Clock class

A pluggable clock used by TokenKeeper so tests can control time.

In production the default Clock reads DateTime.now(). Tests can pass a FixedClock to advance time deterministically.

Implementers

Constructors

Clock()
Creates a real clock backed by DateTime.now().
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
now() DateTime
Returns the current wall-clock time.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited