RefreshFailedEvent class final

Emitted when a refresh attempt fails. failure explains why.

Note: failure is resilify's non-generic Failure value type.

Inheritance

Constructors

RefreshFailedEvent(Failure failure)
Creates a refresh-failure event.
const

Properties

failure Failure
The failure that ended the refresh attempt.
final
hashCode int
The hash code for this object.
no setterinherited
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.

Operators

operator ==(Object other) bool
The equality operator.
inherited