TokenRefreshedEvent constructor
const
TokenRefreshedEvent(
- Token token
Creates a refresh event with the freshly stored token.
Implementation
const TokenRefreshedEvent(this.token);
Creates a refresh event with the freshly stored token.
const TokenRefreshedEvent(this.token);