issuedAt property
The iat (issued-at) claim from the JWT — when the token was minted.
null if the token was not created via tryParseJwt or the JWT has no
iat claim. Use age to get the elapsed time since issuance.
Implementation
final DateTime? issuedAt;