issuer property
The iss (issuer) claim from the JWT — identifies who issued the token.
null if the token was not created via tryParseJwt or the JWT has no
iss claim.
Implementation
final String? issuer;
The iss (issuer) claim from the JWT — identifies who issued the token.
null if the token was not created via tryParseJwt or the JWT has no
iss claim.
final String? issuer;