subject property
The sub (subject) claim from the JWT — typically a user or service ID.
null if the token was not created via tryParseJwt or the JWT has no
sub claim.
Implementation
final String? subject;
The sub (subject) claim from the JWT — typically a user or service ID.
null if the token was not created via tryParseJwt or the JWT has no
sub claim.
final String? subject;