invalidate method
void
invalidate()
Invalidates the cache so the next read fetches from the backing store.
Implementation
void invalidate() {
_loaded = false;
_cache = null;
}
Invalidates the cache so the next read fetches from the backing store.
void invalidate() {
_loaded = false;
_cache = null;
}